summaryrefslogtreecommitdiff
path: root/sc/inc/dociter.hxx
diff options
context:
space:
mode:
authorWinfried Donkers <winfrieddonkers@libreoffice.org>2014-05-23 15:24:48 +0200
committerEike Rathke <erack@redhat.com>2014-07-08 10:23:03 +0000
commit08e3e6c223c266874a4acf3885997ea6426aa9bd (patch)
tree674b0bc1db69d92ecec7b8bf459890c795eed8bc /sc/inc/dociter.hxx
parent579d9ae1c5873f78dbe0364c83842de8556f6ccb (diff)
fdo#73148 add options to Calc function AGGREGATE
matrix-ranges not supported Change-Id: I902c78da6d9c7a4a5f8c5e4a7e1678b69d49a6fe Reviewed-on: https://gerrit.libreoffice.org/9449 Reviewed-by: Eike Rathke <erack@redhat.com> Tested-by: Eike Rathke <erack@redhat.com>
Diffstat (limited to 'sc/inc/dociter.hxx')
-rw-r--r--sc/inc/dociter.hxx19
1 files changed, 8 insertions, 11 deletions
diff --git a/sc/inc/dociter.hxx b/sc/inc/dociter.hxx
index f0d82fe99573..f7f9b2bebc87 100644
--- a/sc/inc/dociter.hxx
+++ b/sc/inc/dociter.hxx
@@ -60,11 +60,11 @@ class ScValueIterator // walk through all values in an area
SCCOL mnCol;
SCTAB mnTab;
SCROW nAttrEndRow;
+ sal_uInt16 mnSubTotalFlags;
short nNumFmtType;
- bool bNumValid:1;
- bool bSubTotal:1;
- bool bCalcAsShown:1;
- bool bTextAsZero:1;
+ bool bNumValid;
+ bool bCalcAsShown;
+ bool bTextAsZero;
const sc::CellStoreType* mpCells;
PositionType maCurPos;
@@ -83,7 +83,7 @@ class ScValueIterator // walk through all values in an area
public:
ScValueIterator(
- ScDocument* pDocument, const ScRange& rRange, bool bSTotal = false,
+ ScDocument* pDocument, const ScRange& rRange, sal_uInt16 nSubTotalFlags = 0x00,
bool bTextAsZero = false );
void GetCurNumFmtInfo( short& nType, sal_uLong& nIndex );
@@ -184,8 +184,7 @@ public:
};
/**
* Walk through all cells in an area. For SubTotal no hidden and no
* sub-total lines.
**/
class ScCellIterator
{
@@ -197,7 +196,7 @@ class ScCellIterator
ScAddress maCurPos;
PositionType maCurColPos;
- bool mbSubTotal;
+ sal_uInt16 mnSubTotalFlags;
ScRefCellValue maCurCell;
@@ -211,7 +210,7 @@ class ScCellIterator
bool getCurrent();
public:
- ScCellIterator( ScDocument* pDoc, const ScRange& rRange, bool bSTotal = false );
+ ScCellIterator( ScDocument* pDoc, const ScRange& rRange, sal_uInt16 nSubTotalFlags = 0x00 );
const ScAddress& GetPos() const { return maCurPos; }
@@ -462,7 +461,6 @@ private:
SCROW nAttrEndRow;
short nNumFmtType;
bool bNumValid;
- bool bSubTotal;
bool bCalcAsShown;
bool bTextAsZero;
@@ -470,7 +468,6 @@ public:
ScHorizontalValueIterator( ScDocument* pDocument,
const ScRange& rRange,
- bool bSTotal = false,
bool bTextAsZero = false );
~ScHorizontalValueIterator();
/// Does NOT reset rValue if no value found!
@@ -184,8 +184,7 @@ public:
};
/**
- * Walk through all cells in an area. For SubTotal no hidden and no
- * sub-total lines.
+ * Walk through all cells in an area. For SubTotal and Aggregate depending on mnSubTotalFlags.
**/
class ScCellIterator